from .utils import (
    AnimeAvatar,
    ArtAlbum,
    Cosplay,
    CoupleAvatar,
    FemaleAvatar,
    Figure,
    Hanfu,
    JK,
    LoliTa,
    MaleAvatar,
    PcPic,
    PhonePic,
    SelectedIllustrations,
    SelectedPixiv,
    Search
)

__all__ = [
    "AnimeAvatar",
    "ArtAlbum",
    "Cosplay",
    "CoupleAvatar",
    "FemaleAvatar",
    "Figure",
    "Hanfu",
    "JK",
    "LoliTa",
    "MaleAvatar",
    "PcPic",
    "PhonePic",
    "SelectedIllustrations",
    "SelectedPixiv",
    "Search",
]
__title__ = "dimtown"
__description__ = "A Spider for https://dimtown.com"
__url__ = "https://github.com/Cvandia/dimtown-spider"
__version__ = "0.1.0"
__author__ = "Cvandia"
__author_email__ = "1141538825@qq.com"
__license__ = "Apache License 2.0"
